@@ -1,5 +1,6 @@
 import base64
 import json
+from collections import OrderedDict
 
 import requests
 
@@ -279,6 +280,20 @@ class APIClient:
                 response_json.get("license_signature"),
             )
 
+            response_json_sig_v2_check_data = json.loads(
+                decoded_data, object_pairs_hook=OrderedDict
+            )
+            response_json_sig_v2_check_data.pop("license_signature")
+            license_signature_v2 = response_json_sig_v2_check_data.pop(
+                "license_signature_v2"
+            )
+            response_json_sig_v2_check_string = json.dumps(
+                response_json_sig_v2_check_data, separators=(",", ":")
+            )
+            self.signature_verifier.verify_license_signature_v2(
+                response_json_sig_v2_check_string.encode(), license_signature_v2
+            )
+
         return response_json
 
     def activate_offline(self, data):
@@ -305,6 +320,20 @@ class APIClient:
                 response_json.get("license_signature"),
             )
 
+            response_json_sig_v2_check_data = response.json(
+                object_pairs_hook=OrderedDict
+            )
+            response_json_sig_v2_check_data.pop("license_signature")
+            license_signature_v2 = response_json_sig_v2_check_data.pop(
+                "license_signature_v2"
+            )
+            response_json_sig_v2_check_string = json.dumps(
+                response_json_sig_v2_check_data, separators=(",", ":")
+            )
+            self.signature_verifier.verify_license_signature_v2(
+                response_json_sig_v2_check_string.encode(), license_signature_v2
+            )
+
         return response_json
 
     def deactivate_offline_dump(
@@ -630,10 +659,11 @@ class APIClient:
 
         return response.json()
 
-    def sso_url(self, product, customer_account_code):
+    def sso_url(self, product, customer_account_code, response_type="token"):
         data = {
             "product": product,
             "customer_account_code": customer_account_code,
+            "response_type": response_type,
         }
 
         response = self.send_request(
